// -*- c++ -*-

#ifndef XMELEGANCE_H
#define XMELEGANCE_H

#include <kparts/mainwindow.h>
#include <kparts/partmanager.h>

class QSplitter;
class QTabWidget;

class KRecentFilesAction;
class KToggleAction;

class DocType;
class DocTypeViewManager;
class DocTypeManager;
class Document;
class DOMTreePart;
class JSConsolePart;
class MessageLogWidget;

/**
 * Main window for XMElegance.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: xmelegance.h,v 1.1.1.1 2001/11/29 18:18:17 rich Exp $
 */
class XMElegance : public KParts::MainWindow
{
    Q_OBJECT

public:
    XMElegance();
    virtual ~XMElegance();

public slots:
    //
    // File handling
    //

    /** Opens the document at the url. */
    void openURL( const KURL &url );
    /** Shows a file dialog then calls @ref openURL */
    void open();

    //
    // View handling
    //

    /** Shows and hides the sidebar. */
    void setSidebarVisible( bool visible );
    /** Shows and hides the message view. */
    void setMessagesVisible( bool visible );

    /** Returns the message log widget. */
    MessageLogWidget *messageLog() const { return msgView; }

    /** Returns the javascript console part. */
    JSConsolePart *jsPart() const { return jsConsole; }

protected:
    /** Install the DocTypeInfo for the specified MIME type. */
    void installDocType( const QString &mime );

    /** Creates the sidebar. */
    void setupSidebar( QWidget *parent );
    /** Creates the document pane. */
    void setupDocViews( QWidget *parent );
    /** Creates the message pane. */
    void setupMessageViews( QWidget *parent );

    /** Creates the KActions for the main window. */
    void setupActions();

    /** Installs the Javascript bindings. */
    void installBindings();

protected slots:
    /** Activates the part for the specified widget (if there is one). */
    void activeViewChanged( QWidget *w );

private:
    DocType *docType() const;

    // Actions
    KRecentFilesAction *recent_files;
    KToggleAction *show_sidebar;
    KToggleAction *show_messages;

    // View Management
    KParts::PartManager *partManager;
    DocTypeViewManager *docViewMng;
    DocTypeManager *docTypeMng;

    // View Containers
    QSplitter *sidebarSplit;
    QSplitter *messageSplit;

    // Sidebar
    QTabWidget *sidebar;
    DOMTreePart *domTree;

    // Document Views
    QTabWidget *docViews;

    // Message Views
    QTabWidget *messages;
    MessageLogWidget *msgView;
    JSConsolePart *jsConsole;
};

#endif // XMELEGANCE_H

// Local Variables:
// c-basic-offset: 4
// End:
