// -*- c++ -*-

#ifndef DOCTYPEMANAGER_H
#define DOCTYPEMANAGER_H

#include <qmap.h>
#include <qobject.h>

#include "doctypeinfo.h"
#include "doctype.h"

typedef QMap<QString,DocTypeInfo> DocTypeMimeMap;
typedef QMapIterator<QString,DocTypeInfo> DocTypeMimeMapIter;

typedef QMap<DocTypeInfo, DocType *> DocTypeInfoMap;
typedef QMapIterator<DocTypeInfo, DocType *> DocTypeInfoMapIter;

/**
 * Manages the loading, unloading and activation of DocTypes.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: doctypemanager.h,v 1.1.1.1 2001/11/29 18:18:08 rich Exp $
 */
class DocTypeManager : public QObject
{
    Q_OBJECT

public:
    DocTypeManager( QObject *obj, const char *name=0 );
    ~DocTypeManager();

    bool activate( const QString &mime );
    bool activate( const DocTypeInfo &info );

    const DocTypeInfo &infoForMimeType( const QString &mime );

    DocType *docType( const QString &mime );
    DocType *docType( const DocTypeInfo &info );

    void loadDocTypeInfo();

protected:
    void add( const DocTypeInfo &info );

    bool loadDocType( const DocTypeInfo &info );
    bool unloadDocType( const DocTypeInfo &info );

private:
    DocTypeMimeMap infoMap;
    DocTypeInfoMap loadedMap;
    DocTypeInfo info;
};

#endif // DOCTYPEMANAGER_H

// Local Variables:
// c-basic-offset: 4
// End:

