#include <kdebug.h>

#include "kjsembed/messagelogwidget.h"

#include "doctypemanager.h"
#include "doctypeviewmanager.h"
#include "global.h"
#include "xmelegance.h"

#include "document.h"
#include "document.moc"

Document::Document( QObject *parent, const char *name )
    : QObject( parent, (name ? name : "document") ),
      nulldocument(true), modified(false), doctype(0)
{
}

Document::Document( const KURL &url, QObject *parent, const char *name )
    : QObject( parent, (name ? name : "document") ),
      nulldocument(false), docurl(url), modified(false), doctype(0)
{
    nulldocument = !openURL( docurl );
}

Document::~Document()
{

}

bool Document::openURL( const KURL &url )
{
    // Get the mime type
    mime = KMimeType::findByURL( url );
    if (!mime) {
	kdDebug() << "openURL for " << url.url() << " could not find out mimetype" << endl;
	return false;
    }
    kdDebug() << "openURL for " << url.url() << " found mimetype " << mime->name() << endl;
    if ( url.filename().endsWith( ".docbook" ) )
	doctype = Global::docTypes()->docType( "text/docbook-xml" );
    else
	doctype = Global::docTypes()->docType( mime->name() );

    if ( doctype )
	kdDebug() << "openURL found doctype " << doctype->info().name() << endl;
    else
	kdDebug() << "openURL did not find a doctype!" << endl;

    return true;
}

void Document::setModified( bool changed )
{
    if ( changed == modified )
	return;

    modified = changed; 
    emit modifiedChanged( modified );
}

void Document::validate()
{
    Global::xmel()->messageLog()->run( "echo Validate!" );
}

// Local Variables:
// c-basic-offset: 4
// End:

